@@ -9,7 +9,8 @@
 """
 from .voyage import simulated_annealing
 from .voyage import ants_colony
+from .voyage import create_visual
 
-__author__ = 'Mark Kozlov'
+__author__ = 'Марк Козлов, Вячеслав Есаков, Артём Радайкин, Александр Савостьянов, Лев Памбухчян'
 
-__version__ = "0.0.7"
+__version__ = "0.0.8"
